@@ -1,8 +1,8 @@
-;;; ai-code.el --- Unified interface for AI coding CLI such as Claude Code, Codex CLI, Gemini CLI, Copilot CLI, Opencode, Grok CLI, Aider CLI, etc -*- lexical-binding: t; -*-
+;;; ai-code.el --- Unified interface for AI coding backends such as Claude Code, Codex CLI, Gemini CLI, Copilot CLI, Opencode, Grok CLI, Aider CLI, etc -*- lexical-binding: t; -*-
 
 ;; Author: Kang Tu <tninja@gmail.com>
-;; Package-Version: 1.45
-;; Package-Revision: 3bb5c3f36e89
+;; Package-Version: 1.52
+;; Package-Revision: 74fd1c0b2db8
 ;; Package-Requires: ((emacs "28.1") (transient "0.8.0") (magit "2.1.0"))
 ;; URL: https://github.com/tninja/ai-code-interface.el
 
@@ -27,18 +27,33 @@
 ;;   - Kiro CLI
 ;;   - CodeBuddy Code CLI
 ;;   - Aider CLI
+;;   - agent-shell
+;;
+;; New User Quick Start:
+;;   1) Minimal setup:
+;;
+;;      (use-package ai-code
+;;        :config
+;;        (ai-code-set-backend 'codex)
+;;        (global-set-key (kbd "C-c a") #'ai-code-menu))
+;;
+;;   2) First 60 seconds:
+;;      - C-c a a : Start AI CLI session
+;;      - C-c a c : Ask AI to change current function/region
+;;      - C-c a q : Ask question only (no code change)
+;;      - C-c a z : Jump back to active AI session buffer
 ;;
 ;; Basic configuration example:
 ;;
 ;; (use-package ai-code
 ;;   :config
-;;   ;; use codex as backend, other options are 'gemini, 'github-copilot-cli, 'opencode, 'grok, 'claude-code-ide, 'claude-code-el, 'claude-code, 'cursor, 'kiro, 'codebuddy, 'aider
+;;   ;; use codex as backend, other options are 'gemini, 'github-copilot-cli, 'opencode, 'grok, 'claude-code-ide, 'claude-code-el, 'claude-code, 'cursor, 'kiro, 'codebuddy, 'aider, 'agent-shell
 ;;   (ai-code-set-backend 'codex) ;; set your preferred backend
 ;;   (global-set-key (kbd "C-c a") #'ai-code-menu)
 ;;   ;; Optional: Enable @ file completion in comments and AI sessions
 ;;   (ai-code-prompt-filepath-completion-mode 1)
-;;   ;; Optional: Ask AI to run test after code changes, for a tighter build-test loop
-;;   (setq ai-code-auto-test-type 'test-after-change)
+;;   ;; Optional: Configure AI test prompting mode (e.g., ask about running tests/TDD) for a tighter build-test loop
+;;   (setq ai-code-auto-test-type 'ask-me)
 ;;   ;; Optional: In the AI session buffer (Evil normal state), SPC triggers the prompt entry UI
 ;;   (with-eval-after-load 'evil (ai-code-backends-infra-evil-setup))
 ;;   (global-auto-revert-mode 1)
@@ -102,6 +117,7 @@
 (declare-function ai-code-backends-infra--session-buffer-p "ai-code-backends-infra" (buffer))
 
 (declare-function ai-code--process-word-for-filepath "ai-code-prompt-mode" (word git-root-truename))
+(declare-function ai-code-call-gptel-sync "ai-code-prompt-mode" (question))
 
 ;; Default aliases are set when a backend is applied via `ai-code-select-backend`.
 
@@ -146,19 +162,109 @@ with a newline separator."
     (concat "Follow TDD principles - write the failing test first, then implement the minimal code to make it pass. Only update test and source code. Run the tests and follow up with the test result (fix code if there is error)."
             (or pattern ""))))
 
+(defconst ai-code--auto-test-type-ask-choices
+  '(("Run tests after code change" . test-after-change)
+    ("Test driven development: Write test first" . tdd)
+    ("Do not run tests" . nil))
+  "Choices for resolving the auto test suffix when `ai-code-auto-test-type` is `ask-me`.")
+
+(defun ai-code--read-auto-test-type-choice ()
+  "Read and return one prompt test type for this send action."
+  (let* ((choice (completing-read "Choose test prompt type for this send: "
+                                  (mapcar #'car ai-code--auto-test-type-ask-choices)
+                                  nil t nil nil
+                                  (caar ai-code--auto-test-type-ask-choices)))
+         (choice-cell (assoc choice ai-code--auto-test-type-ask-choices)))
+    (if choice-cell
+        (cdr choice-cell)
+      'test-after-change)))
+
+;;;###autoload
+(defcustom ai-code-use-gptel-classify-prompt nil
+  "Whether to use GPTel to classify prompts in `ask-me` auto test mode.
+When non-nil and `ai-code-auto-test-type` is not nil, classify whether
+the current prompt is about code changes. If not, skip test type selection
+and do not append auto test suffix."
+  :type 'boolean
+  :group 'ai-code)
+
+(defun ai-code--gptel-classify-prompt-code-change (prompt-text)
+  "Classify whether PROMPT-TEXT requests code changes using GPTel.
+Return one of: `code-change`, `non-code-change`, or `unknown`."
+  (let ((classification
+         (condition-case err
+             (if (require 'gptel nil t)
+                 (let* ((raw-answer (ai-code-call-gptel-sync
+                                     (concat "Classify whether this user prompt requests code changes in a repository.\n"
+                                             "Reply with exactly one token: CODE_CHANGE or NOT_CODE_CHANGE.\n"
+                                             "Treat edit/refactor/implement/fix/add/remove/update/tests as CODE_CHANGE.\n"
+                                             "Treat explain/summarize/discuss/review without editing as NOT_CODE_CHANGE.\n\n"
+                                             "Prompt:\n" prompt-text)))
+                        (answer (upcase (string-trim (or raw-answer "")))))
+                   (cond
+                    ((string-match-p "\\`CODE_CHANGE\\b" answer) 'code-change)
+                    ((string-match-p "\\`NOT_CODE_CHANGE\\b" answer) 'non-code-change)
+                    (t 'unknown)))
+               'unknown)
+           (error
+            (message "GPTel prompt classification failed: %s" (error-message-string err))
+            'unknown))))
+    (message "GPTel prompt classification result: %s" classification)
+    classification))
+
+(defun ai-code--resolve-auto-test-type-for-send (&optional prompt-text)
+  "Resolve the concrete auto test type for current send action for PROMPT-TEXT."
+  (pcase ai-code-auto-test-type
+    ('ask-me
+     (if ai-code-use-gptel-classify-prompt
+         (pcase (ai-code--gptel-classify-prompt-code-change prompt-text)
+           ('code-change (ai-code--read-auto-test-type-choice))
+           ('non-code-change nil)
+           (_ (ai-code--read-auto-test-type-choice)))
+       (ai-code--read-auto-test-type-choice)))
+    ('test-after-change
+     (if ai-code-use-gptel-classify-prompt
+         (when (eq (ai-code--gptel-classify-prompt-code-change prompt-text)
+                   'code-change)
+           'test-after-change)
+       'test-after-change))
+    ('tdd
+     (if ai-code-use-gptel-classify-prompt
+         (when (eq (ai-code--gptel-classify-prompt-code-change prompt-text)
+                   'code-change)
+           'tdd)
+       'tdd))
+    (_ nil)))
+
+(defun ai-code--auto-test-suffix-for-type (type)
+  "Return prompt suffix for auto test TYPE."
+  (pcase type
+    ('test-after-change ai-code-test-after-code-change-suffix)
+    ('tdd (ai-code--test-after-code-change--resolve-tdd-suffix))
+    (_ nil)))
+
+(defun ai-code--resolve-auto-test-suffix-for-send (&optional prompt-text)
+  "Resolve auto test suffix for current send action for PROMPT-TEXT."
+  (ai-code--auto-test-suffix-for-type
+   (ai-code--resolve-auto-test-type-for-send prompt-text)))
+
+(defun ai-code--with-auto-test-suffix-for-send (orig-fun prompt-text)
+  "Resolve and bind auto test suffix before sending PROMPT-TEXT."
+  (let ((ai-code-auto-test-suffix (ai-code--resolve-auto-test-suffix-for-send prompt-text)))
+    (funcall orig-fun prompt-text)))
+
+(unless (advice-member-p #'ai-code--with-auto-test-suffix-for-send
+                         'ai-code--write-prompt-to-file-and-send)
+  (advice-add 'ai-code--write-prompt-to-file-and-send
+              :around
+              #'ai-code--with-auto-test-suffix-for-send))
+
 (defun ai-code--test-after-code-change--set (symbol value)
   "Set SYMBOL to VALUE and update related suffix behavior."
   (set-default symbol value)
   (set symbol value)
-  (pcase value
-    ('test-after-change
-     (setq ai-code-auto-test-suffix
-           ai-code-test-after-code-change-suffix))
-    ('tdd
-     (setq ai-code-auto-test-suffix
-           (ai-code--test-after-code-change--resolve-tdd-suffix)))
-    (_
-     (setq ai-code-auto-test-suffix nil))))
+  (setq ai-code-auto-test-suffix
+        (ai-code--auto-test-suffix-for-type value)))
 
 (defun ai-code--apply-auto-test-type (value)
   "Set `ai-code-auto-test-type` and refresh related suffix."
@@ -170,6 +276,7 @@ with a newline separator."
   "Select how prompts request tests after code changes."
   :type '(choice (const :tag "Use test after code change prompt" test-after-change)
                  (const :tag "Use TDD Red+Green prompt" tdd)
+                 (const :tag "Ask every time" ask-me)
                  (const :tag "Off" nil))
   :set #'ai-code--test-after-code-change--set
   :group 'ai-code)
@@ -276,6 +383,7 @@ Otherwise switch to AI CLI buffer."
   :reader (lambda (_prompt _initial-input _history)
             (let* ((choices '(("Use test after code change prompt" . test-after-change)
                               ("Use TDD Red+Green prompt" . tdd)
+                              ("Ask every time" . ask-me)
                               ("Off" . nil)))
                    (choice (completing-read "Test after code change: "
                                             (mapcar #'car choices)
@@ -284,7 +392,9 @@ Otherwise switch to AI CLI buffer."
                 (ai-code--apply-auto-test-type value)
                 (message "Auto test type set to %s; prompt suffix is now %s"
                          (or value "off")
-                         (or ai-code-auto-test-suffix "cleared"))
+                         (if (eq value 'ask-me)
+                             "ask each send"
+                           (or ai-code-auto-test-suffix "cleared")))
                 value))))
 
 (defun ai-code--select-backend-description (&rest _)
@@ -315,7 +425,8 @@ Shows the current backend label to the right."
     ("q" "Ask question (C-u: clipboard)" ai-code-ask-question)
     ("x" "Explain code in scope" ai-code-explain)
     ("<SPC>" "Send command (C-u: context)" ai-code-send-command)
-    ("@" "Add context (C-u: clear)" ai-code-context-action)
+    ("@" "Context (add/show/clear)" ai-code-context-action)
+    ("C" "Create file or dir with AI" ai-code-create-file-or-dir)
     ]
 
    ["AI Agile Development"
@@ -325,7 +436,7 @@ Shows the current backend label to the right."
     ("v" "Pull or Review Code Change"  ai-code-pull-or-review-diff-file)
     ;; ("b" "Send prompt block to AI" ai-code-prompt-send-block)
     ("!" "Run Current File or Command" ai-code-run-current-file-or-shell-cmd)
-    ("b" "Build / Test project"               ai-code-build-or-test-project)
+    ("b" "Build / Test (AI follow-up)"   ai-code-build-or-test-project)
     ;; ("I" "Insert function name at point" ai-code-insert-function-at-point)
     ("K" "Create or open task file" ai-code-create-or-open-task-file)
     ("n" "Take notes from AI session region" ai-code-take-notes)
